/*
 * AT-SPI - Assistive Technology Service Provider Interface
 * (Gnome Accessibility Project; http://developer.gnome.org/projects/gap)
 *
 * Copyright 2001, 2002 Sun Microsystems Inc.,
 * Copyright 2001, 2002 Ximian, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#pragma once

#include "glib.h"

#include "atspi-accessible.h"
#include "atspi-action.h"
#include "atspi-collection.h"
#include "atspi-component.h"
#include "atspi-constants.h"
#include "atspi-device-listener.h"
#include "atspi-document.h"
#include "atspi-editabletext.h"
#include "atspi-event-listener.h"
#include "atspi-hyperlink.h"
#include "atspi-hypertext.h"
#include "atspi-image.h"
#include "atspi-matchrule.h"
#include "atspi-misc.h"
#include "atspi-registry.h"
#include "atspi-relation.h"
#include "atspi-selection.h"
#include "atspi-stateset.h"
#include "atspi-table-cell.h"
#include "atspi-table.h"
#include "atspi-text.h"
#include "atspi-types.h"
#include "atspi-value.h"

#include "atspi-gmain.h"

#include "atspi-enum-types.h"

#include "atspi-version.h"
